@@ -1,2 +1,2 @@
-from .parser import Parser
-from .tokens import Expression
\ No newline at end of file
+from .parser import parse
+from .tokens import Expression
